netapp_ontap.models.metrocluster_diag_details API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.metrocluster_diag_details`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class MetroclusterDiagDetailsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MetroclusterDiagDetails object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aggregate: Aggregate GET`

    The aggregate field of the metrocluster_diag_details.

  `checks: List[MetroclusterDiagCheck] GET`

    Collection of MetroCluster checks done for component.

  `cluster: Cluster GET`

    The cluster field of the metrocluster_diag_details.

  `node: Node GET`

    The node field of the metrocluster_diag_details.

  `timestamp: ImpreciseDateTime GET`

    Time check was done.

    Example: 2016-03-10T22:35:16.000+0000

  `volume: Volume GET`

    The volume field of the metrocluster_diag_details.